justbases._errors module — justbases 0.07 documentation

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- justbases »
- justbases package »

# justbases._errors module

Errors.

exception `justbases._errors.` `BasesAssertError`

  Bases: `justbases._errors.BasesError`

  For assertion failures.

exception `justbases._errors.` `BasesError`

  Bases: `exceptions.Exception`

  Supertype of all errors for this package.

exception `justbases._errors.` `BasesInvalidOperationError`(op, other=None)

  Bases: `justbases._errors.BasesError`

  Invalid operation.

exception `justbases._errors.` `BasesValueError`(value, param, msg=None)

  Bases: `justbases._errors.BasesError`

  Raised when a parameter has an unacceptable value.

  May also be raised when the parameter has an unacceptable type.

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- justbases »
- justbases package »